@@ -1,6 +1,5 @@
 import os
 import json
-import shutil
 import subprocess
 import sys
 import asyncio
@@ -15,7 +14,7 @@ import socket
 import websockets
 from websockets.exceptions import InvalidStatusCode, ConnectionClosed, ConnectionClosedOK
 from logging.handlers import TimedRotatingFileHandler
-from tickerdax.constants import Envs, KeyTypes, NAME, URL, GLOBAL_INSTANCE_NAME, DEFAULT_REDIS_CONFIG
+from tickerdax.constants import Envs, KeyTypes, NAME, URL, GLOBAL_INSTANCE_NAME, REDS_CONFIG_FILE
 from docker.errors import DockerException
 from datetime import datetime, timedelta, timezone
 from tickerdax import formatting
@@ -82,8 +81,10 @@ class TickerDax:
         # module level dictionary for caching during runtime
         self._runtime_cache = {}
 
-        self._cache_folder = os.environ.get(Envs.CACHE_ROOT.value, os.path.join(tempfile.gettempdir(), NAME, 'cache'))
+        self._tmp_cache_folder = os.path.join(tempfile.gettempdir(), NAME, 'cache')
+        self._cache_folder = os.environ.get(Envs.CACHE_ROOT.value, self._tmp_cache_folder)
         self._logs_folder = os.environ.get(Envs.LOGS_FOLDER.value, os.path.join(tempfile.gettempdir(), NAME, 'logs'))
+
         self._logger = logging.getLogger(self.__class__.__name__)
         self._logger.setLevel(level=logging.DEBUG)
 
@@ -268,15 +269,13 @@ class TickerDax:
 
         # if in the official docker image, try starting redis manually and
         if os.environ.get(Envs.OFFICIAL_DOCKER_IMAGE.value) and attempts < 1:
-            os.makedirs(self._cache_folder, exist_ok=True)
-            if not os.path.exists(DEFAULT_REDIS_CONFIG):
-                shutil.copy(DEFAULT_REDIS_CONFIG, os.path.join(self._cache_folder, 'redis.conf'))
             try:
+                os.makedirs(self._tmp_cache_folder, exist_ok=True)
+                self._logger.info('Attempting to start redis server on local system...')
                 subprocess.Popen(
-                    f'redis-server {self._cache_folder} --port {self._redis_host_port}',
+                    f'redis-server {REDS_CONFIG_FILE} --port {self._redis_host_port}',
                     shell=True
                 )
-                self._logger.info('Attempting to start redis server on local system...')
                 time.sleep(5)
                 if self._set_redis_client():
                     return
@@ -318,7 +317,7 @@ class TickerDax:
             ports={
                 f'{self._redis_container_port}/tcp': (self._redis_server_address, self._redis_host_port)
             },
-            volumes=[f'{self._cache_folder}:/data'],
+            volumes=[f'{self._cache_folder}:/tmp/{NAME}/cache'],
             detach=True
         )
 
@@ -581,6 +580,14 @@ class TickerDax:
             )
         return result
 
+    def save(self):
+        """
+        Save the data in redis to disk.
+        """
+        self._logger.info('Saving data to disk..')
+        self.redis_client.bgsave()
+        self._logger.info('Save complete!')
+
     @staticmethod
     @atexit.register
     def on_shutdown():
@@ -589,9 +596,7 @@ class TickerDax:
         """
         self = globals().get(GLOBAL_INSTANCE_NAME)
         if self:
-            self._logger.info('Saving data to disk..')
-            self.redis_client.bgsave()
-            self._logger.info('Save complete!')
+            self.save()
 
     def validate_api_key(self,  key_type):
         """
