@@ -4,7 +4,7 @@ from enum import Enum
 NAME = 'tickerdax'
 URL = f'https://{NAME}.com'
 GLOBAL_INSTANCE_NAME = f'global_{NAME}_client_instance'
-DEFAULT_REDIS_CONFIG = '/var/tickerdax/redis.conf'
+REDS_CONFIG_FILE = '/var/tickerdax/redis.conf'
 
 
 class BaseEnum(str, Enum):
