@@ -7,6 +7,7 @@ class Downloader(ConfigBase):
     """
     Downloads data from the tickerdax.com data api using a provided config.
     """
+
     def __init__(self, config, client_kwargs=None, till_now=False):
         super(Downloader, self).__init__(config, client_kwargs)
         self._missing_data = {}
@@ -79,14 +80,10 @@ class Downloader(ConfigBase):
                 missing_items += len(self.client.missing_values)
                 self.track_missing_ranges(route)
 
-            if downloaded_items:
-                self._logger.info('Saving download to disk..')
-                self.client.redis_client.bgsave()
-
             self._logger.info('Preparing summary...')
             show_download_summary(
                 cached_items=cached_items,
                 downloaded_items=downloaded_items,
                 missing_items=missing_items,
                 missing_ranges=self.get_missing_ranges()
-            )
\ No newline at end of file
+            )
