@@ -31,9 +31,7 @@ class Streamer(ConfigBase):
                     client_kwargs={'log_connection': False},
                     till_now=True
                 )
-                self._logger.info('Saving data to disk..')
-                self.client.redis_client.bgsave()
-                self._logger.info('Save complete!')
+                self.client.save()
 
             # stream updates to the cache indefinitely
             self._logger.info(f'Starting streams...')
